import type { MindElixirInstance, MindElixirData } from './index';
import * as customLink from './customLink';
import * as summaryOperation from './summary';
export type MindElixirMethods = typeof methods;
/**
 * Methods that mind-elixir instance can use
 *
 * @public
 */
declare const methods: {
    init(this: MindElixirInstance, data: MindElixirData): Error | undefined;
    createSummary: (this: MindElixirInstance) => void;
    removeSummary: (this: MindElixirInstance, id: string) => void;
    selectSummary: (this: MindElixirInstance, el: summaryOperation.SummarySvgGroup) => void;
    unselectSummary: (this: MindElixirInstance) => void;
    renderSummary: (this: MindElixirInstance) => void;
    editSummary: (this: MindElixirInstance, el: summaryOperation.SummarySvgGroup) => void;
    createLink: (this: MindElixirInstance, from: import("./index").Topic, to: import("./index").Topic, isInitPaint?: boolean | undefined, obj?: customLink.LinkItem | undefined) => void;
    removeLink: (this: MindElixirInstance, linkSvg?: import("./index").CustomSvg | undefined) => void;
    selectLink: (this: MindElixirInstance, link: import("./index").CustomSvg) => void;
    hideLinkController: (this: MindElixirInstance) => void;
    showLinkController: (this: MindElixirInstance, p2x: number, p2y: number, p3x: number, p3y: number, linkItem: customLink.LinkItem, fromData: customLink.LinkControllerData, toData: customLink.LinkControllerData) => void;
    reshapeNode: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    insertSibling: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    insertBefore: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    insertParent: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    addChild: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    copyNode: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    moveUpNode: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    moveDownNode: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    removeNode: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    moveNode: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    moveNodeBefore: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    moveNodeAfter: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    beginEdit: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    setNodeTopic: (this: MindElixirInstance, ...args: unknown[]) => Promise<void>;
    selectNode: (this: MindElixirInstance, targetElement: import("./index").Topic, isNewNode?: boolean | undefined, e?: MouseEvent | undefined) => void;
    unselectNode: (this: MindElixirInstance) => void;
    selectNodes: (this: MindElixirInstance, targetElements: import("./index").Topic[]) => void;
    unselectNodes: (this: MindElixirInstance) => void;
    selectNextSibling: (this: MindElixirInstance) => boolean;
    selectPrevSibling: (this: MindElixirInstance) => boolean;
    selectFirstChild: (this: MindElixirInstance) => void;
    selectParent: (this: MindElixirInstance) => void;
    getDataString: (this: MindElixirInstance) => string;
    getData: (this: MindElixirInstance) => MindElixirData;
    getDataMd: (this: MindElixirInstance) => string;
    enableEdit: (this: MindElixirInstance) => void;
    disableEdit: (this: MindElixirInstance) => void;
    scale: (this: MindElixirInstance, scaleVal: number) => void;
    toCenter: (this: MindElixirInstance) => void;
    install: (this: MindElixirInstance, plugin: (instance: MindElixirInstance) => void) => void;
    focusNode: (this: MindElixirInstance, el: import("./index").Topic) => void;
    cancelFocus: (this: MindElixirInstance) => void;
    initLeft: (this: MindElixirInstance) => void;
    initRight: (this: MindElixirInstance) => void;
    initSide: (this: MindElixirInstance) => void;
    setLocale: (this: MindElixirInstance, locale: string) => void;
    expandNode: (this: MindElixirInstance, el: import("./index").Topic, isExpand?: boolean | undefined) => void;
    refresh: (this: MindElixirInstance, data?: MindElixirData | undefined) => void;
    getObjById: (id: string, data: import("./types").NodeObj) => import("./types").NodeObj | null;
    generateNewObj: (this: MindElixirInstance) => import("./types").NodeObjExport;
    layout: (this: MindElixirInstance) => void;
    linkDiv: (this: MindElixirInstance, mainNode?: import("./index").Wrapper | undefined) => void;
    editTopic: (this: MindElixirInstance, el: import("./index").Topic) => void;
    createWrapper: (this: MindElixirInstance, nodeObj: import("./types").NodeObj, omitChildren?: boolean | undefined) => {
        grp: import("./index").Wrapper;
        top: import("./index").Parent;
        tpc: import("./index").Topic;
    };
    createParent: (this: MindElixirInstance, nodeObj: import("./types").NodeObj) => {
        p: import("./index").Parent;
        tpc: import("./index").Topic;
    };
    createChildren: (this: MindElixirInstance, wrappers: import("./index").Wrapper[]) => import("./index").Children;
    createTopic: (this: MindElixirInstance, nodeObj: import("./types").NodeObj) => import("./index").Topic;
    findEle: (id: string, instance?: MindElixirInstance | undefined) => import("./index").Topic;
    changeTheme: (this: MindElixirInstance, theme: import("./types").Theme, shouldRefresh?: boolean) => void;
};
export default methods;
